==> csounddart-0.0.1.tar.gz: lib/csound.dart <==
import 'dart:async';
import 'package:csounddart/audio_utilities.dart';
import 'package:flutter/services.dart';
import "csound_stub.dart"
// ignore: uri_does_not_exist
if(dart.library.io) 'csoundnative.dart'
// ignore: uri_does_not_exist
if(dart.library.html) 'csoundweb.dart';


Function appStartup = getAppStartup();


abstract class Csound {
  static const MethodChannel _channel =
      const MethodChannel('csound');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }


  //Constructor
  factory Csound() => getCsoundDart();


  //Compile the CSD string as text
  int compileCsdText(String text);

  //Compiles the ORC string as text
  int compileOrc(String orc);

  //Compiles the CSD string as file
  int compileCsd(String csdPath);

  //Reads the score as string and computes it if performance is running
  int readScore(String text);

  //starts performance
  int perform();

  //stops performance
  void stop();

  //Sets control channel "channelName" with value
  void setControlChannel(String channelName, double value);

  //Returns the value of control channel "channelName". Not working on desktop yet
  // (It is recommanded to use setControlChannelCallback instead, see below).
  Future<double> getControlChannel(String channelName);

  //Associates the callback of a control channel with a function. Multiple callbacks can be registered for one channel. 
  // It is user responsibility to pass a function with a double value as single argument for callback argument.
  void setControlChannelCallback(String channelName, Function(double) callback);

  //Sets String channel "channelName" with string value
  void setStringChannel(String channelName, String value);

  //Returns the value of String channel "channelName". Not working yet 
  Future<String> getStringChannel(String channelName);

  //Associates the callback of a String channel with a function. Multiple callbacks can be registered for one channel. 
  // It is user responsibility to pass a function with a String value as single argument for callback argument.
  void setStringChannelCallback(String channelName, Function callback);

  // Sets the corresponding table with values
  void setTable(int table, List<double> values);

  //Assiciates the callback of table with a function.
  void setTableCallback(int table, Function callback);


  // The following methods are only available on desktop
  void setAudioChannelCallback(String name, Function(ConcurrentBuffer buf) callback);

  Future<double> evalCode(String code);

  Future<int> getKsmps();
  Future<int> getNchnls();
  Future<int> getSr();
}

==> csounddart-0.0.2.tar.gz: lib/csound.dart <==
import 'dart:async';
import 'package:flutter/services.dart';
import "csound_stub.dart"
// ignore: uri_does_not_exist
if(dart.library.io) 'csoundnative.dart'
// ignore: uri_does_not_exist
if(dart.library.html) 'csoundweb.dart';


Function appStartup = getAppStartup();


abstract class Csound {
  static const MethodChannel _channel =
      const MethodChannel('csound');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }


  //Constructor
  factory Csound() => getCsoundDart();


  //Compile the CSD string as text
  int compileCsdText(String text);

  //Compiles the ORC string as text
  int compileOrc(String orc);

  //Compiles the CSD string as file
  int compileCsd(String csdPath);

  //Reads the score as string and computes it if performance is running
  int readScore(String text);

  //starts performance
  int perform();

  //stops performance
  void stop();

  //Sets control channel "channelName" with value
  void setControlChannel(String channelName, double value);

  //Returns the value of control channel "channelName". Not working on desktop yet
  // (It is recommanded to use setControlChannelCallback instead, see below).
  Future<double> getControlChannel(String channelName);

  //Associates the callback of a control channel with a function. Multiple callbacks can be registered for one channel. 
  // It is user responsibility to pass a function with a double value as single argument for callback argument.
  void setControlChannelCallback(String channelName, Function(double) callback);

  //Sets String channel "channelName" with string value
  void setStringChannel(String channelName, String value);

  //Returns the value of String channel "channelName". Not working yet 
  Future<String> getStringChannel(String channelName);

  //Associates the callback of a String channel with a function. Multiple callbacks can be registered for one channel. 
  // It is user responsibility to pass a function with a String value as single argument for callback argument.
  void setStringChannelCallback(String channelName, Function callback);

  // Sets the corresponding table with values
  void setTable(int table, List<double> values);

  //Assiciates the callback of table with a function.
  void setTableCallback(int table, Function callback);


  // The following methods are only available on desktop
  void setAudioChannelCallback(String name, Function callback);


  Future<double> evalCode(String code);

  Future<int> getKsmps();
  Future<int> getNchnls();
  Future<int> getSr();
}
